'''
GEMS Directives
'''
__author__    = 'Brad Kizzort'
__copyright__ = 'Copyright 2012, Harris Corporation'
from errors import UnknownParameterError
class GemsDirective(object):    #Normative
    '''
    GEMS directives are similar to spacecraft commands.  There is a directive name
    and a set of parameter=value pairs that can be sent to the GEMS device to change
    device configuration.
    '''
    def __init__(self, name, device, args=dict()):  #Non-normative
        '''
        The Gems Directive constructor is intended for the internal creation
        of a directive catalog.  Use GemsDevice.lookupDirective() to find a 
        catalog entry.
        '''
        self.name   = name
        self.device = device
        self.arg    = args
    def setValues(self, **args):
        '''Set the Parameter values from the Keyword=Value pairs passed
        '''
        params = args.keys()
        for param in params:
            if self.arg.has_key(param):
                self.arg[param].setValue(args[param])
            else:
                raise UnknownParameterError('GEMS Parameter {0} not defined for {1}'
                                            .format(param, self.name))
    def __repr__(self):
        return "Directive('{0}')".format(self.name)
    def send(self):
        '''Send the directive to the device with the defined parameter values
        '''
        args = dict()
        for argName in self.arg.keys():
            args[argName] = self.arg[argName].value()
        self.device.send(self.name, **args)